@@ -1,19 +1,5 @@
 # requirements
 
-def additional_tests():
-    import doctest
-    import unittest
-    return unittest.TestSuite((
-        doctest.DocFileSuite('../../docs/index.rst',
-                                module_relative=True),
-        doctest.DocFileSuite('../../docs/distributions.rst',
-                                module_relative=True),
-        doctest.DocFileSuite('../../docs/metadata.rst',
-                                module_relative=True),
-        doctest.DocFileSuite('../../docs/indexes.rst',
-                                module_relative=True),
-    ))
-
 
 def _checkSample(testcase, installed):
     try:
@@ -34,9 +20,19 @@ def _checkClassifiers(testcase, installed):
       'Intended Audience :: Developers',
       'License :: OSI Approved :: Python Software Foundation License',
       'Operating System :: OS Independent',
-      'Programming Language :: Python :: 2.5',
       'Programming Language :: Python :: 2.6',
       'Programming Language :: Python :: 2.7',
+      'Programming Language :: Python :: 3.2',
+      'Programming Language :: Python :: 3.3',
+      'Programming Language :: Python :: Implementation :: CPython',
+      'Programming Language :: Python :: Implementation :: PyPy',
       'Topic :: Software Development :: Libraries :: Python Modules',
       'Topic :: System :: Software Distribution',
     ])
+
+
+def _defaultMetadataVersion():
+    import sys
+    if sys.version_info[:2] > (2, 6):
+        return '1.1'
+    return '1.0'
